#!/usr/bin/env python

import numpy as np
import pyproj

class Waypoint:
    def dms2dd(coordinate : str):
        split = coordinate.split('.')
        if 4 != len(split):
            return 0.0

        direction = split[0][1]
        degrees = float(split[0][1:])
        minutes = float(split[1])
        seconds = float(split[2]) * (float(split[3]) / 1000.0)

        dd = degrees + minutes / 60.0 + seconds / (60 * 60)
        if 'E' == direction or 'S' == direction:
            dd *= -1.0

        return dd

    def __init__(self, name : str, latitude : float, longitude : float):
        self.name = name
        self.coordinate = np.array([ latitude, longitude ])

    def __str__(self):
        return 'Name: ' + self.name + ', Lat: ' + str(self.coordinate[0]) + ', Lon: ' + str(self.coordinate[1])

    def haversine(self, other):
        geodesic = pyproj.Geod(ellps='WGS84')
        forward, backward, distance = geodesic.inv(self.coordinate[1], self.coordinate[0], other.coordinate[1], other.coordinate[0])
        return distance / 1000.0

    def bearing(self, other):
        geodesic = pyproj.Geod(ellps='WGS84')
        forward, backward, distance = geodesic.inv(self.coordinate[1], self.coordinate[0], other.coordinate[1], other.coordinate[0])
        return forward
